{***************************************************************************
                        data.pas   -  Runtime datas.
                             -------------------
    copyright            : (C) 2002 Alberto Lohmann
    email                : lohmann@users.sourceforge.net
    app. url             : http://cloxten.sourceforge.net
    project url          : http://sourceforge.net/projects/cloxten
 ***************************************************************************

 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************}

// * This file is part of Cloxten program.



unit data;

interface

uses
  {$IFDEF LINUX} Libc {$ENDIF},
  QControls,
  QDialogs,
  SysUtils;

type
  TData = class
    procedure CheckFiles;
    procedure RecData;
    procedure RecVersion;
    procedure RetrieveData;
    procedure MsgData;
  end;

var
  ConfigFile, HOME_DIR, VersionFile, Str: String;
  CONFIG_EXISTS                         : Boolean = False;
  CONFIG_STAT_OK                        : Boolean;
  Dat                                   : TextFile;

implementation

uses mainform, optionsform, mail;

procedure TData.CheckFiles;
begin
  ConfigFile := HOME_DIR + '/.cloxten/config';
  VersionFile := HOME_DIR + '/.cloxten/version';

  if DirectoryExists(HOME_DIR + '/.cloxten') = False then begin
    Try
      { As no "config dir" found, I supose it's the first user contact with
        Cloxten. So I show he/she some notices. }
      Form2.NoControls;
      Form2.PageControl1.Pages[2].Show;
      Form2.ShowModal;

      { ... and now, I do the rest... }
      CreateDir(HOME_DIR + '/.cloxten');
      FileCreate(ConfigFile);
      FileCreate(VersionFile);
      RecData;
      RecVersion;
    except
      ShowMessage('Unable to create/read CLOXTEN dir, config and version files.');
      CONFIG_EXISTS := False;
    end;
  end
  else begin
    if FileExists(ConfigFile) = False then begin
      CONFIG_EXISTS := False;
      Try
        FileCreate(ConfigFile);
        RecData;
        if FileExists(ConfigFile) = True then CONFIG_EXISTS := True;
      except
        ShowMessage('Unable to create/read config file ' + ConfigFile);
      end;
    end
    else CONFIG_EXISTS := True;

    if FileExists(VersionFile) = False then begin
      Try
        FileCreate(VersionFile);
        RecVersion;
      except
        ShowMessage('Unable to create/read version file ' + VersionFile);
      end;
    end
    else begin
      AssignFile(Dat, VersionFile);
      Reset(Dat);
      readln(Dat, Str);
      CloseFile(Dat);
      if Str <> '0.1.2 Pre-Alpha' then RecVersion;
    end;
  end;
end;

procedure TData.RecData;
begin
  AssignFile(Dat, ConfigFile);
  Rewrite(Dat);
  writeln(Dat, '#This file was generated by Cloxten 0.1.2 PA.');
  writeln(Dat, '#Do not edit it, unless you know what you are doing.');
  writeln(Dat, '#Cloxten can be found in: http://cloxten.sourceforge.net');
  writeln(Dat, '#');

  writeln(Dat, '#[Actions: Basic:]');
  if Form2.CheckBox1.Checked = True
    then writeln(Dat, 'yes')
    else writeln(Dat, 'no');
  if Form2.CheckBox2.Checked = True
    then writeln(Dat, 'yes')
    else writeln(Dat, 'no');
  if Form2.RadioButton1.Checked = True then writeln(Dat, '1');
  if Form2.RadioButton2.Checked = True then begin
    writeln(Dat, '2');
    writeln(Dat, optionsform.FileToPlay);
  end;
  writeln(Dat, '#');

  writeln(Dat, '#[Actions: Advanced:]');
  if Form2.RadioButton3.Checked = True then writeln(Dat, '1');
  if Form2.RadioButton4.Checked = True then begin
    writeln(Dat, '2');
    MsgData;
    writeln(Dat, optionsform.MsgArgsStr);
    writeln(Dat, Form4.Edit2.Text);
    writeln(Dat, Form4.Edit3.Text);
    writeln(Dat, Form4.Edit4.Text);
    writeln(Dat, Form4.Edit5.Text);
    if Form4.CheckBox1.Checked = True
      then writeln(Dat, 'yes')
      else writeln(Dat, 'no');
    end;
  if Form2.RadioButton5.Checked = True then begin
    writeln(Dat, '3');
    writeln(Dat, optionsform.FileToRun);
  end;
  writeln(Dat, '#');

  writeln(Dat, '#[Settings: Alarm:]');
  if Form2.RadioButton6.Checked = True then writeln(Dat, '1');
  if Form2.RadioButton7.Checked = True then writeln(Dat, '2');
  if Form2.CheckBox3.Checked = True
    then writeln(Dat, 'yes')
    else writeln(Dat, 'no');
  writeln(Dat, '#');

  writeln(Dat, '#[Settings: Counter:]');
  if Form2.RadioButton8.Checked = True then writeln(Dat, '1');
  if Form2.RadioButton9.Checked = True then writeln(Dat, '2');
  if Form2.CheckBox4.Checked = True
    then writeln(Dat, 'yes')
    else writeln(Dat, 'no');
  writeln(Dat, '#');

  writeln(Dat, '#[Settings: General:]');
  if Form2.CheckBox5.Checked = True
    then writeln(Dat, 'yes')
    else writeln(Dat, 'no');
  if Form2.CheckBox6.Checked = True
    then writeln(Dat, 'yes')
    else writeln(Dat, 'no');
  if Form2.CheckBox7.Checked = True
    then writeln(Dat, 'yes')
    else writeln(Dat, 'no');
  if Form2.CheckBox8.Checked = True
    then writeln(Dat, 'yes')
    else writeln(Dat, 'no');
  if Form2.CheckBox9.Checked = True
    then writeln(Dat, 'yes')
    else writeln(Dat, 'no');
  if Form2.RadioButton10.Checked = True then writeln(Dat, '1');
  if Form2.RadioButton11.Checked = True then writeln(Dat, '2');
  writeln(Dat, '#');
  writeln(Dat, '#EOF');

  CloseFile(Dat);
end;

procedure TData.RecVersion;
begin
  AssignFile(Dat, VersionFile);
  Rewrite(Dat);
  writeln(Dat, '0.1.2 Pre-Alpha');
  CloseFile(Dat);
end;

procedure TData.RetrieveData;
begin
  AssignFile(Dat, ConfigFile);
  Reset(Dat);
  readln(Dat, Str);

  SetLength(Str, 35); // Any later version will not recuse an early one.
  if Str='#This file was generated by Cloxten' then begin
   { Start }
    readln(Dat);
    readln(Dat);
    readln(Dat);

    { Actions: Basic: }
    readln(Dat);
    readln(Dat, Str);
    if Str = 'yes' then Form2.CheckBox1.Checked := True
      else Form2.CheckBox1.Checked := False;
    readln(Dat, Str);
    if Str = 'yes' then Form2.CheckBox2.Checked := True
      else Form2.CheckBox2.Checked := False;
    readln(Dat, Str);
    case StrToInt(Str) of
      1 : Form2.RadioButton1.Checked := True;
      2 : Form2.RadioButton2.Checked := True;
    else Form2.RadioButton1.Checked := True;
    end;
    if Form2.RadioButton2.Checked = True
      then readln(Dat, optionsform.FileToPlay);
    readln(Dat);

    { Actions: Advanced: }
    readln(Dat);
    readln(Dat, Str);
    case StrToInt(Str) of
      1 : Form2.RadioButton3.Checked := True;
      2 : Form2.RadioButton4.Checked := True;
      3 : Form2.RadioButton5.Checked := True;
    else Form2.RadioButton3.Checked := True;
    end;
    if Form2.RadioButton4.Checked = True
      then begin
        readln(Dat, optionsform.MsgArgsStr);
        readln(Dat, Str);
        Form4.Edit2.Text := Str;
        readln(Dat, Str);
        Form4.Edit3.Text := Str;
        readln(Dat, Str);
        Form4.Edit4.Text := Str;
        readln(Dat, Str);
        Form4.Edit5.Text := Str;
        readln(Dat, Str);
        if Str = 'no' then Form4.CheckBox1.Checked := False
          else Form4.CheckBox1.Checked := True;
      end
      else begin
        if SysUtils.FileExists(HOME_DIR + '/.cloxten/mail.txt')
          then SysUtils.DeleteFile(HOME_DIR + '/.cloxten/mail.txt');
      end;
    if Form2.RadioButton5.Checked = True
      then readln(Dat, optionsform.FileToRun);
    readln(Dat);

    { Settings: Alarm: }
    readln(Dat);
    readln(Dat, Str);
    case StrToInt(Str) of
      1 : Form2.RadioButton6.Checked := True;
      2 : Form2.RadioButton7.Checked := True;
    else Form2.RadioButton7.Checked := True;
    end;
    readln(Dat, Str);
    if Str = 'es' then Form2.CheckBox3.Checked := True
      else Form2.CheckBox3.Checked := False;
    readln(Dat);

    { Settings: Counter: }
    readln(Dat);
    readln(Dat, Str);
    case StrToInt(Str) of
      1 : Form2.RadioButton8.Checked := True;
      2 : Form2.RadioButton9.Checked := True;
    else Form2.RadioButton9.Checked := True;
    end;
    readln(Dat, Str);
    if Str = 'no' then Form2.CheckBox4.Checked := False
      else Form2.CheckBox4.Checked := True;
    readln(Dat);

    { Settings: General: }
    readln(Dat);
    readln(Dat, Str);
    if Str = 'yes' then Form2.CheckBox5.Checked := True
      else Form2.CheckBox5.Checked := False;
    readln(Dat, Str);
    if Str = 'no' then Form2.CheckBox6.Checked := False
      else Form2.CheckBox6.Checked := True;
    readln(Dat, Str);
    if Str = 'yes' then Form2.CheckBox7.Checked := True
      else Form2.CheckBox7.Checked := False;
    readln(Dat, Str);
    if Str = 'yes' then Form2.CheckBox8.Checked := True
      else Form2.CheckBox8.Checked := False;
    readln(Dat, Str);
    if Str = 'no' then Form2.CheckBox9.Checked := False
      else Form2.CheckBox9.Checked := True;
    readln(Dat, Str);
    case StrToInt(Str) of
      1 : Form2.RadioButton10.Checked := True;
      2 : Form2.RadioButton11.Checked := True;
    else Form2.RadioButton10.Checked := True;
    end;
    readln(Dat);

    readln(Dat, Str);
    CloseFile(Dat);

    if Str = '#EOF'
      then CONFIG_STAT_OK := True
      else CONFIG_STAT_OK := False;

    { Finish }
  end
  else CONFIG_STAT_OK := False;

{  if CONFIG_STAT_OK = False then ShowMessage(
    'Something is wrong at the end of config file. ' +
    'Check you configuration in the Control Window ' +
    'and record a new file by clicking on OK button.');}


  { If necessary, do this only once. }
  if (CONFIG_STAT_OK = False) and (Form2.Visible = False) then begin
    ShowMessage(
    'Something is wrong with config file. ' +
    'I will open the Control Window. Check your configuration ' +
    'and then, record a new file by clicking on "Save" button.');
    Form2.NoInfo;
    Form2.ShowModal;
    CONFIG_STAT_OK := True; // Even if not.
    //I just don't want to see it again during this section.
  end;

end;

procedure TData.MsgData;
begin
  // Create mail args. string to use.
  Str := EmptyStr;
  if Form4.Edit5.Text <> ''
    then Str := ' -s ''' + Form4.Edit5.Text + '''';
  if Form4.Edit3.Text <> ''
    then Str := Str + ' -c ''' + Form4.Edit3.Text + '''';
  if Form4.Edit4.Text <> ''
    then Str := Str + ' -b ''' + Form4.Edit4.Text + '''';
  optionsform.MsgArgsStr := Str + ' ''' + Form4.Edit2.Text + '''';
end;

end.
